<?php
/**
 * Load Translations
 */
function zcmail_load_translation_file() {
	$plugin_path = plugin_basename( dirname( __FILE__ ) .'/../translations' );
	load_plugin_textdomain( 'zero-conf-mail', '', $plugin_path );
}

/**
 * Send a mail
 * Parameters: (str) to, (str) from, (str) subject, (str) body
 */
function zcmail_sendmail($to, $from, $subject, $body) {
	// Add message footer
	$body .= "\n\n---\n" . __('Sent with Zero Conf Mail: ', 'zero-conf-mail');
	$body .= __('http://www.nkuttler.de/wordpress/zero-conf-mail/', 'zero-conf-mail');
	$body .= "\n\n" . __('Blog: ', 'zero-conf-mail');
	$body .= get_bloginfo('home');
	$body .= "\n" . __('IP  : ', 'zero-conf-mail');
	$body .= $_SERVER['REMOTE_ADDR'];
	mail(
		$to,
		'[' . get_bloginfo('name') . '] ' . $subject,
		$body,
		"From: $from"
	);
}
/**
 * Validate all parameters
 * Parameters: (array) post data, (array) configuration options
 * Return: (bool) validates?
 * TODO: Useful error messages
 */
function zcmail_validates($input, $defs) {
	foreach($defs as $def => $value) {
		if ($value['type'] == 'text' || $value['type'] == 'textarea') {
			// catch all mandatory fields that haven't been modified
			if ( $value['must'] == __('Enabled', 'zero-conf-mail') && $input[$def] == $value['label'] ) {
				//echo "error: " . $input[$def] . " unchanged";
				return false;
			}
			// catch all mandatory fields that are empty
			elseif ( $value['must'] == __('Enabled', 'zero-conf-mail') && $input[$def] == '' ) {
				//echo "error: " . $value['label'] . $input[$def] . " empty";
				return false;
			}
		}
		if ($value['type'] == 'email') {
			// catch all mandatory invalid mail addresses
			if ( $value['must'] == 'Enabled' && $value['type'] == 'email' && !is_email($input[$def]) ) {
				//echo "error: " . $input[$def] . " no mail";
				return false;
			}
		}
	}
	return true;
}

/**
 * Print the mail form for visitors
 * Parameters: void
 */
function zcmail_printform() {
	$option = get_option('zcmail'); ?>
	<form action="" method="post"> <?php
	foreach($option['fields'] as $field => $values) {
		switch($values['type']) {
			case 'text':
			case 'email':
				zcmail_input("zcmail[$field]", zcmail_get_value($values['label'], $_POST['zcmail'][$field]), zcmail_get_value_bool($values['label'], $_POST['zcmail'][$field]) );
				break;
			case 'textarea':
				zcmail_textarea("zcmail[$field]", zcmail_get_value($values['label'], $_POST['zcmail'][$field]), zcmail_get_value_bool($values['label'], $_POST['zcmail'][$field]) );
				break;
			case 'submit':
				zcmail_submit( $values['label'] );
				break;
		}
	} ?>
	</form> <?php
	if ($option['config']['homelink'] == 'Below the form' ) {
		zcmail_homelink();
	}
	elseif ($option['config']['homelink'] == 'In the footer') {
		add_action('wp_footer', 'zcmail_homelink');
	}
}



/*
 * Print the value the user submitted earlier, or the default.
 * Parameters: (str) default, (str) submitted post data
 * Return: (str) previous value
 */
function zcmail_get_value($default, $submitted) {
	if ($submitted) {
		return $submitted;
	}
	else {
		return $default;
	}
}

/*
 * Tell us if the value the user submitted earlier was the default value.
 * Parameters: (str) default, (str) submitted post data
 * Return: (str) previous value
 */
function zcmail_get_value_bool($default, $submitted) {
	if (!$submitted || $submitted == $default) {
		return true;
	}
	else {
		return false;
	}
}

/**
 * Print an input field.
 * Parameters: (str) form input name, (str) lanel, (bool) use JavaScript, (int) size
 */
function zcmail_input( $name, $label, $js, $size=40 ) { ?>
	<input type="text" size="<?php echo $size ?>" name="<?php echo $name ?>" value="<?php echo $label ?>"<?php if ($js) zcmail_jsnippet( $label ); ?> class="zcmail_text" />
	<?php
}

/**
 * Print a textarea, hardcoded size so far
 * Parameters: (str) form input name, (str) lanel, (bool) use JavaScript
 */
function zcmail_textarea( $name, $label, $js ) { ?>
	<textarea rows="10" cols="50" name="<?php echo $name ?>" class="zcmail_textarea" <?php if ($js) zcmail_jsnippet($label) ?> ><?php echo $label; ?></textarea><?php
}

/**
 *  Print a submit putton
 *  Parameters: (str) button label
 */
function zcmail_submit( $label ) { ?>
	<input type="submit" id="submit" value="<?php echo $label ?>" class="zcmail_submit" /> <?php
}

/**
 * Print a select dropdown
 * Parameters: (str) form input name, (str) current value, (array) choices
 */
function zcmail_select( $name, $value, array $choices ) { ?>
	<select name="<?php echo $name ?>"><?php
	foreach ($choices as $choice) {
		if ($choice == $value ) { ?>
			<option value="<?php echo $choice ?>" selected><?php echo __($choice, 'zero-conf-mail') ?></option> <?
		}
		else {?>
			<option value="<?php echo $choice ?>" ><?php echo __($choice, 'zero-conf-mail') ?></option> <?
		}
	}
	?>
	</select>
	<?php
}

/**
 * Print a checkbox, checked or unchecked
 * Parameters: (str) from input name (bool) checked
 * TODO allow users to use this
 */
function zcmail_checkbox( $name, $true ) {
	if ($true == 'Enabled') { ?>
		<input type="checkbox" name="<?php echo $name ?>" value="checked" checked /> <?php
	}
	else { ?>
		<input type="checkbox" name="<?php echo $name ?>" value="checked" /> <?php
	}
}

/**
 * Print two radio select buttons for true/false choice
 * Parameters: (str) form input name, (str) true/false
 */
function zcmail_bool( $name, $true ) {
	if ($true == __('Enabled', 'zero-conf-mail') ) { ?>
		<input type="radio" name="<?php echo $name ?>" value="true" checked />
		<input type="radio" name="<?php echo $name ?>" value="false" /> <?php
	}
	else { ?>
		<input type="radio" name="<?php echo $name ?>" value="true" />
		<input type="radio" name="<?php echo $name ?>" value="false" checked /> <?php
	}
}

/**
 * Print the javascript for input fields for the mail form for visitors
 * $param will be deleted or filled in
 * Prameters: (str) $param
 */
function zcmail_jsnippet($param) {
	echo " onfocus=\"if(this.value=='$param'){this.value=''};\" ";
	echo " onblur=\"if(this.value==''){this.value='$param'}\" ";
}

/**
 * The link to the plugin site.
 */
function zcmail_homelink() { ?>
	<span class="zcmail_home"><?php _e('Mail form powered by ', 'zero-conf-mail') ?><a href="<?php _e('http://www.nkuttler.de/wordpress/zero-conf-mail/', 'zero-conf-mail') ?>">Zero Conf Mail</a> <?
}
