<?php
/*
Plugin Name: Zero Conf Mail
Plugin URI: http://www.nkuttler.de/wordpress/zero-conf-mail/
Author: Nicolas Kuttler
Author URI: http://www.nkuttler.de/
Description: Mail form that doesn't need any configuration.
Version: 0.1.4
*/

/**
 * This file		Functions that are always needed
 * inc/admin.php	Admin stuff
 * inc/page.php		Things only needed when the shortcode is on a page/post
 */

/**
 * Check if we run as admin and load all that is needed
 */
function zcmail_load() {
	if (is_admin()) {
		require_once('inc/admin.php');
		require_once('inc/page.php');
		add_action('init', 'zcmail_load_translation_file');
		add_action('admin_menu', 'zcmail_add_pages');
		register_activation_hook(__FILE__, 'zcmail_activate');
		register_uninstall_hook(__FILE__, 'zcmail_deactivate');
	}
}
zcmail_load();

/**
 * Add a shortcode to include the mail form.
 * Do not check for valid email etc. at the moment.
 */
add_shortcode('zcmail', 'zcmail_shortcode');

/**
 * The shortcode.
 * Load translations + functions when on a page
 * Parse POST data and/or show the form.
 */
function zcmail_shortcode() {
	require_once('inc/page.php');
	add_action('init', 'zcmail_load_translation_file'); ?>
	<div id="zcmail"><?php
	$option = get_option('zcmail');
	if ( isset($_POST['zcmail'] )) {
		if ( zcmail_validates($_POST['zcmail'], $option['fields'] ) ) {
			// TODO, hardcoded field names...
			// FIX don't allow users to delete default fields :)
			if ( $_POST['zcmail']['from'] ) {
				$from = $_POST['zcmail']['from'];
			}
			else {
				$from = 'Bug 01 - no from field defined';
			}
			if ( $_POST['zcmail']['subject'] ) {
				$subject = $_POST['zcmail']['subject'];
			}
			else {
				$subject = 'Bug 02 - no subject field defined';
			}
			if ( $_POST['zcmail']['body'] ) {
				$message = $_POST['zcmail']['body'];
			}
			else {
				$message = 'Bug 03 - no message field defined';
			}
			foreach($_POST['zcmail'] as $field => $values) {
				// TODO I guess this should be safe, as a[] = 0 => a[0] = 0
				// Only add custom fields
				if (is_integer($field)) {
					$message .= "\n";
					$message .= $option['fields'][$field]['label'] . ": $values";
				}
			}
			zcmail_sendmail($option['config']['to'], $from, $subject, $message );

			echo '<div class="zcmail_success">';
			_e('Your message has been sent. Thank you!', 'zero-conf-mail');
			echo '</div>';
		}
		else {
			echo '<div class="zcmail_error">';
			_e('Please fill out all fields!', 'zero-conf-mail');
			echo '</div>';
			zcmail_printform();
		}
	}
	else {
		zcmail_printform();
	} ?>
	</div> <?php
}

/**
 * Perform (basic) sanitization of user input.
 * Parameters: (str) string
 * Return: (str)
 */
function zcmail_sanitize($string) {
	$string = htmlspecialchars($string, ENT_QUOTES);;
	return $string;
}
?>
